==> dataclay-3.1.0.tar.gz: dataclay-3.1.0/README.md <==

<h1 align="center">

![dataClay](https://github.com/bsc-dom/dataclay/blob/main/docs/_static/dataclay-full.png)

</h1>

<p align="center">
  <a href="https://github.com/bsc-dom/dataclay/actions/workflows/tests.yml"><img alt="Tests" src="https://github.com/bsc-dom/dataclay/actions/workflows/tests.yml/badge.svg" /></a>
  <a href="https://dataclay.readthedocs.io/en/latest/?badge=latest"><img alt="Documentation Status" src="https://readthedocs.org/projects/dataclay/badge/?version=latest" /></a>
  <a href="https://pypi.org/project/dataclay/"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/dataclay" /></a>
  <a href="https://pypi.org/project/dataclay/"><img alt="PyPI - Format" src="https://img.shields.io/pypi/format/dataclay" /></a>
  <a href="https://github.com/bsc-dom/dataclay/blob/main/LICENSE.txt"><img alt="License" src="https://img.shields.io/github/license/bsc-dom/dataclay" /></a>
  <a href="https://badge.fury.io/py/dataclay"><img src="https://badge.fury.io/py/dataclay.svg" alt="PyPI version" height="18"></a>
  <a href="https://pepy.tech/project/dataclay"><img alt="Pypi Downloads" src="https://pepy.tech/badge/dataclay" /></a>
</p>

dataClay is a distributed data store that enables applications to store and access objects in the same format they have in memory, and executes object methods within the data store. These two main features accelerate both the development of applications and their execution.

## Installation

To install dataClay, you can use [pip](https://pip.pypa.io):

```bash
$ pip install dataclay
```

Alternatively, you can obtain the latest source code from [GitHub](https://github.com/bsc-dom/dataclay):

```bash
$ git clone https://github.com/bsc-dom/dataclay.git
$ cd dataclay
$ pip install .
```

## Documentation

dataClay has usage and reference documentation at [dataclay.readthedocs.io](https://dataclay.readthedocs.io/en/latest/)

## Contributing

We welcome contributions to dataClay. Please see the [Contributing](https://dataclay.readthedocs.io/en/latest/contributing.html) for more details.

## Maintainers

- [@alexbarcelo](https://github.com/alexbarcelo) (Alex Barcelo)
- [@aqueralt](https://github.com/aqueralt) (Anna Queralt)
- [@marcmonfort](https://github.com/marcmonfort) (Marc Monfort)

## Other resources

[BSC official website](https://www.bsc.es/dataclay)

==> dataclay-4.0.0.tar.gz: dataclay-4.0.0/README.md <==

<h1 align="center">

![dataClay](https://github.com/bsc-dom/dataclay/blob/main/docs/_static/dataclay-full.png)

</h1>

<p align="center">
  <a href="https://github.com/bsc-dom/dataclay/actions/workflows/tests.yml"><img alt="Tests" src="https://github.com/bsc-dom/dataclay/actions/workflows/tests.yml/badge.svg" /></a>
  <a href="https://dataclay.readthedocs.io/en/latest/?badge=latest"><img alt="Documentation Status" src="https://readthedocs.org/projects/dataclay/badge/?version=latest" /></a>
  <a href="https://pypi.org/project/dataclay/"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/dataclay" /></a>
  <a href="https://pypi.org/project/dataclay/"><img alt="PyPI - Format" src="https://img.shields.io/pypi/format/dataclay" /></a>
  <a href="https://github.com/bsc-dom/dataclay/blob/main/LICENSE.txt"><img alt="License" src="https://img.shields.io/github/license/bsc-dom/dataclay" /></a>
  <a href="https://badge.fury.io/py/dataclay"><img src="https://badge.fury.io/py/dataclay.svg" alt="PyPI version" height="18"></a>
  <a href="https://pepy.tech/project/dataclay"><img alt="Pypi Downloads" src="https://pepy.tech/badge/dataclay" /></a>
</p>

dataClay is a distributed data store that enables applications to store and access objects in the same format they have in memory, and executes object methods within the data store. These two main features accelerate both the development of applications and their execution.

## Installation

To install dataClay, you can use [pip](https://pip.pypa.io):

```bash
pip install dataclay
```

Alternatively, you can obtain the latest source code from [GitHub](https://github.com/bsc-dom/dataclay):

```bash
git clone https://github.com/bsc-dom/dataclay.git
cd dataclay
pip install .
```

## Documentation

dataClay has usage and reference documentation at [dataclay.readthedocs.io](https://dataclay.readthedocs.io/en/latest/)

## Contributing

We welcome contributions to dataClay. Please see the [Contributing](https://dataclay.readthedocs.io/en/latest/contributing.html) for more details.

## Maintainers

- [@alexbarcelo](https://github.com/alexbarcelo) (Alex Barcelo)
- [@aqueralt](https://github.com/aqueralt) (Anna Queralt)
- [@marcmonfort](https://github.com/marcmonfort) (Marc Monfort)

## Other resources

[BSC official website](https://www.bsc.es/dataclay)
